## Infrared Thermal Camera

### Introduction
An upper computer program receiving 32*24 thermal data from MLX90640 using GY-MCU90640.

### Credits

Part of source code comes from [GY-MCU90640-on-PC](https://github.com/autogyro/GY-MCU90640-on-PC)

This package is developed by Donghua Chen with MIT license. 